@@ -8,14 +8,15 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 import socket
+
+from itertools import count, groupby
+
+from ansible.module_utils.common.network import is_masklen, to_netmask
 from ansible.module_utils.six import iteritems
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
-    is_masklen,
-    to_netmask,
-)
 
 
 def remove_command_from_config_list(interface, cmd, commands):
@@ -44,9 +45,7 @@ def reverify_diff_py35(want, have):
     for each_want in want:
         diff = True
         for each_have in have:
-            if each_have == sorted(each_want) or sorted(each_have) == sorted(
-                each_want
-            ):
+            if each_have == sorted(each_want) or sorted(each_have) == sorted(each_want):
                 diff = False
         if diff:
             return True
@@ -78,7 +77,7 @@ def new_dict_to_set(input_dict, temp_list, test_set, count=0):
                 temp_list.append(k)
                 for each in v:
                     if isinstance(each, dict):
-                        if [True for i in each.values() if type(i) == list]:
+                        if [True for i in each.values() if isinstance(i, list)]:
                             new_dict_to_set(each, temp_list, test_set, count)
                         else:
                             new_dict_to_set(each, temp_list, test_set, 0)
@@ -86,10 +85,7 @@ def new_dict_to_set(input_dict, temp_list, test_set, count=0):
                 if v is not None:
                     test_dict.update({k: v})
                 try:
-                    if (
-                        tuple(iteritems(test_dict)) not in test_set
-                        and count == input_dict_len
-                    ):
+                    if tuple(iteritems(test_dict)) not in test_set and count == input_dict_len:
                         test_set.add(tuple(iteritems(test_dict)))
                         count = 0
                 except TypeError:
@@ -157,10 +153,7 @@ def filter_dict_having_none_value(want, have):
                     if have.get(k):
                         dict_val = have.get(k).get(key)
                         test_key_dict.update({key: dict_val})
-                elif (
-                    k == "ipv6"
-                    and value.lower() != have.get(k)[0].get(key).lower()
-                ):
+                elif k == "ipv6" and value.lower() != have.get(k)[0].get(key).lower():
                     # as multiple IPV6 address can be configured on same
                     # interface, for replace state in place update will
                     # actually create new entry, which isn't as expected
@@ -179,10 +172,7 @@ def filter_dict_having_none_value(want, have):
                         dict_val = have.get(k)[0].get(key)
                         test_key_dict.update({key: dict_val})
                 elif have.get(k):
-                    if (
-                        k == "ipv6"
-                        and value.lower() != have.get(k)[0].get(key).lower()
-                    ):
+                    if k == "ipv6" and value.lower() != have.get(k)[0].get(key).lower():
                         dict_val = have.get(k)[0].get(key)
                         test_key_dict.update({key: dict_val})
                 if test_key_dict:
@@ -195,11 +185,7 @@ def filter_dict_having_none_value(want, have):
                 if each.get("secondary"):
                     want_ip = each.get("address").split("/")
                     have_ip = have.get("ipv4")
-                    if (
-                        len(want_ip) > 1
-                        and have_ip
-                        and have_ip[0].get("secondary")
-                    ):
+                    if len(want_ip) > 1 and have_ip and have_ip[0].get("secondary"):
                         have_ip = have_ip[0]["address"].split(" ")[0]
                         if have_ip != want_ip[0]:
                             diff_ip = True
@@ -230,16 +216,12 @@ def validate_ipv4(value, module):
         address = value.split("/")
         if len(address) != 2:
             module.fail_json(
-                msg="address format is <ipv4 address>/<mask>, got invalid format {0}".format(
-                    value
-                )
+                msg="address format is <ipv4 address>/<mask>, got invalid format {0}".format(value),
             )
 
         if not is_masklen(address[1]):
             module.fail_json(
-                msg="invalid value for mask: {0}, mask should be in range 0-32".format(
-                    address[1]
-                )
+                msg="invalid value for mask: {0}, mask should be in range 0-32".format(address[1]),
             )
 
 
@@ -248,16 +230,14 @@ def validate_ipv6(value, module):
         address = value.split("/")
         if len(address) != 2:
             module.fail_json(
-                msg="address format is <ipv6 address>/<mask>, got invalid format {0}".format(
-                    value
-                )
+                msg="address format is <ipv6 address>/<mask>, got invalid format {0}".format(value),
             )
         else:
             if not 0 <= int(address[1]) <= 128:
                 module.fail_json(
                     msg="invalid value for mask: {0}, mask should be in range 0-128".format(
-                        address[1]
-                    )
+                        address[1],
+                    ),
                 )
 
 
@@ -393,3 +373,51 @@ def get_interface_type(interface):
         return "Serial"
     else:
         return "unknown"
+
+
+def get_ranges(data):
+    """
+    Returns a generator object that yields lists of
+    consecutive integers from a list of integers.
+    """
+    for _k, group in groupby(data, lambda t, c=count(): int(t) - next(c)):
+        yield list(group)
+
+
+def numerical_sort(string_int_list):
+    """Sorts list of integers that are digits in numerical order."""
+
+    as_int_list = []
+
+    for vlan in string_int_list:
+        as_int_list.append(int(vlan))
+    as_int_list.sort()
+    return as_int_list
+
+
+def vlan_list_to_range(cmd):
+    """
+    Converts a comma separated list of vlan IDs
+    into ranges.
+    """
+    ranges = []
+    for v in get_ranges(cmd):
+        ranges.append("-".join(map(str, (v[0], v[-1])[: len(v)])))
+    return ",".join(ranges)
+
+
+def vlan_range_to_list(vlans):
+    result = []
+    if vlans:
+        for part in vlans:
+            if part == "none":
+                break
+            if "-" in part:
+                a, b = part.split("-")
+                a, b = int(a), int(b)
+                result.extend(range(a, b + 1))
+            else:
+                a = int(part)
+                result.append(a)
+        return numerical_sort(result)
+    return result
