@@ -22,10 +22,12 @@ from __future__ import absolute_import, division, print_function
 
 
 __metaclass__ = type
+
 DOCUMENTATION = """
 module: ios_vlans
 short_description: Resource module to configure VLANs.
-description: This module provides declarative management of VLANs on Cisco IOS network
+description:
+  This module provides declarative management of VLANs on Cisco IOS network
   devices.
 version_added: 1.0.0
 author: Sumit Jaiswal (@justjais)
@@ -43,54 +45,54 @@ options:
     suboptions:
       name:
         description:
-        - Ascii name of the VLAN.
-        - NOTE, I(name) should not be named/appended with I(default) as it is reserved
-          for device default vlans.
+          - Ascii name of the VLAN.
+          - NOTE, I(name) should not be named/appended with I(default) as it is reserved
+            for device default vlans.
         type: str
       vlan_id:
         description:
-        - ID of the VLAN. Range 1-4094
+          - ID of the VLAN. Range 1-4094
         type: int
         required: true
       mtu:
         description:
-        - VLAN Maximum Transmission Unit.
-        - Refer to vendor documentation for valid values.
+          - VLAN Maximum Transmission Unit.
+          - Refer to vendor documentation for valid values.
         type: int
       state:
         description:
-        - Operational state of the VLAN
+          - Operational state of the VLAN
         type: str
         choices:
-        - active
-        - suspend
+          - active
+          - suspend
       remote_span:
         description:
-        - Configure as Remote SPAN VLAN
+          - Configure as Remote SPAN VLAN
         type: bool
       shutdown:
         description:
-        - Shutdown VLAN switching.
+          - Shutdown VLAN switching.
         type: str
         choices:
-        - enabled
-        - disabled
+          - enabled
+          - disabled
       private_vlan:
         description:
-        - Options for private vlan configuration.
+          - Options for private vlan configuration.
         type: dict
         suboptions:
           type:
             description:
-            - Private VLAN type
+              - Private VLAN type
             type: str
             choices:
-            - primary
-            - isolated
-            - community
+              - primary
+              - isolated
+              - community
           associated:
             description:
-            - "List of private VLANs associated with the primary . Only works with `type: primary`."
+              - "List of private VLANs associated with the primary . Only works with `type: primary`."
             type: list
             elements: int
   running_config:
@@ -122,15 +124,16 @@ options:
         connection to remote host is not required.
     type: str
     choices:
-    - merged
-    - replaced
-    - overridden
-    - deleted
-    - rendered
-    - gathered
-    - parsed
+      - merged
+      - replaced
+      - overridden
+      - deleted
+      - rendered
+      - gathered
+      - parsed
     default: merged
 """
+
 EXAMPLES = """
 # Using merged
 
@@ -157,20 +160,20 @@ EXAMPLES = """
 - name: Merge provided configuration with device configuration
   cisco.ios.ios_vlans:
     config:
-    - name: Vlan_10
-      vlan_id: 10
-      state: active
-      shutdown: disabled
-      remote_span: true
-    - name: Vlan_20
-      vlan_id: 20
-      mtu: 610
-      state: active
-      shutdown: enabled
-    - name: Vlan_30
-      vlan_id: 30
-      state: suspend
-      shutdown: enabled
+      - name: Vlan_10
+        vlan_id: 10
+        state: active
+        shutdown: disabled
+        remote_span: true
+      - name: Vlan_20
+        vlan_id: 20
+        mtu: 610
+        state: active
+        shutdown: enabled
+      - name: Vlan_30
+        vlan_id: 30
+        state: suspend
+        shutdown: enabled
     state: merged
 
 # After state:
@@ -238,9 +241,9 @@ EXAMPLES = """
 - name: Override device configuration of all VLANs with provided configuration
   cisco.ios.ios_vlans:
     config:
-    - name: Vlan_10
-      vlan_id: 10
-      mtu: 1000
+      - name: Vlan_10
+        vlan_id: 10
+        mtu: 1000
     state: overridden
 
 # After state:
@@ -300,25 +303,25 @@ EXAMPLES = """
 - name: Replaces device configuration of listed VLANs with provided configuration
   cisco.ios.ios_vlans:
     config:
-    - vlan_id: 20
-      name: Test_VLAN20
-      mtu: 700
-      shutdown: disabled
-    - vlan_id: 50
-      name: pvlan-isolated
-      private_vlan:
-        type: isolated
-    - vlan_id: 60
-      name: pvlan-community
-      private_vlan:
-        type: community
-    - vlan_id: 70
-      name: pvlan-primary
-      private_vlan:
-        type: primary
-        associated:
-          - 50
-          - 60
+      - vlan_id: 20
+        name: Test_VLAN20
+        mtu: 700
+        shutdown: disabled
+      - vlan_id: 50
+        name: pvlan-isolated
+        private_vlan:
+          type: isolated
+      - vlan_id: 60
+        name: pvlan-community
+        private_vlan:
+          type: community
+      - vlan_id: 70
+        name: pvlan-primary
+        private_vlan:
+          type: primary
+          associated:
+            - 50
+            - 60
 
     state: replaced
 
@@ -399,8 +402,8 @@ EXAMPLES = """
 - name: Delete attributes of given VLANs
   cisco.ios.ios_vlans:
     config:
-    - vlan_id: 10
-    - vlan_id: 20
+      - vlan_id: 10
+      - vlan_id: 20
     state: deleted
 
 # After state:
@@ -426,7 +429,7 @@ EXAMPLES = """
 # 1005 trnet 101005     1500  -      -      -        ibm  -        0      0
 
 # Using Deleted without any config passed
-#"(NOTE: This will delete all of configured vlans attributes)"
+# "(NOTE: This will delete all of configured vlans attributes)"
 
 # Before state:
 # -------------
@@ -616,20 +619,20 @@ EXAMPLES = """
 - name: Render the commands for provided  configuration
   cisco.ios.ios_vlans:
     config:
-    - name: Vlan_10
-      vlan_id: 10
-      state: active
-      shutdown: disabled
-      remote_span: true
-    - name: Vlan_20
-      vlan_id: 20
-      mtu: 610
-      state: active
-      shutdown: enabled
-    - name: Vlan_30
-      vlan_id: 30
-      state: suspend
-      shutdown: enabled
+      - name: Vlan_10
+        vlan_id: 10
+        state: active
+        shutdown: disabled
+        remote_span: true
+      - name: Vlan_20
+        vlan_id: 20
+        mtu: 610
+        state: active
+        shutdown: enabled
+      - name: Vlan_30
+        vlan_id: 30
+        state: suspend
+        shutdown: enabled
     state: rendered
 
 # Module Execution Result:
@@ -745,8 +748,8 @@ EXAMPLES = """
 #             "vlan_id": 1005
 #         }
 #     ]
-
 """
+
 RETURN = """
 before:
   description: The configuration as structured data prior to module invocation.
@@ -808,16 +811,11 @@ def main():
         supports_check_mode=True,
     )
 
-    if _is_l2_device(module) or module.params.get("state") in [
-        "rendered",
-        "parsed",
-    ]:
+    if _is_l2_device(module) or module.params.get("state") in ["rendered", "parsed"]:
         result = Vlans(module).execute_module()
         module.exit_json(**result)
     else:
-        module.fail_json(
-            """Resource VLAN is not valid for the target device.""",
-        )
+        module.fail_json("""Resource VLAN is not valid for the target device.""")
 
 
 if __name__ == "__main__":
