@@ -18,6 +18,7 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 GENERATOR_VERSION = "1.0"
@@ -25,7 +26,7 @@ GENERATOR_VERSION = "1.0"
 
 DOCUMENTATION = """
 module: iosxr_l2_interfaces
-short_description: L2 interfaces resource module
+short_description: Resource Module to configure L2 interfaces.
 description: This module manages the Layer-2 interface attributes on Cisco IOS-XR
   devices.
 version_added: 1.0.0
@@ -119,8 +120,19 @@ options:
           list when configuring Q-in-any vlan as input. Note, that this option is
           valid only with respect to Sub-Interface and is not valid when configuring
           for Interface.
+        - This option is DEPRECATED and replaced with qvlan,
+          this attribute will be removed after 2026-06-01.
         type: list
         elements: int
+      qvlan:
+        description:
+        - 802.1Q VLAN configuration. Note that it can accept either 2 VLAN IDs when
+          configuring Q-in-Q VLAN, or it will accept 1 VLAN ID and 'any' as input
+          list when configuring Q-in-any vlan as input. Note, that this option is
+          valid only with respect to Sub-Interface and is not valid when configuring
+          for Interface.
+        type: list
+        elements: str
       propagate:
         description:
         - Propagate Layer 2 transport events. Note that it will work only when the
@@ -668,6 +680,7 @@ commands:
 """
 
 from ansible.module_utils.basic import AnsibleModule
+
 from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.argspec.l2_interfaces.l2_interfaces import (
     L2_InterfacesArgs,
 )
