@@ -24,17 +24,19 @@ options:
       - Creates a backup file including the timestamp information so you can
         get the original file back if you overwrote it incorrectly.
     type: bool
-    default: no
+    default: false
   create_on_missing:
     description:
       - Creates the UCS based on the value of C(src), if the file does not already
         exist on the remote system.
+      - When set to C(false), with C(fail_on_missing) set to C(false) the module will return no change
+        if the ucs file is missing on device.
     type: bool
-    default: yes
+    default: true
   dest:
     description:
       - A directory to save the UCS file into.
-      - This option is mandatory when C(only_create_file) is set to C(no).
+      - This option is mandatory when C(only_create_file) is set to C(false).
     type: path
   encryption_password:
     description:
@@ -43,35 +45,39 @@ options:
   fail_on_missing:
     description:
       - Make the module fail if the UCS file on the remote system is missing.
+      - This option always takes precedence over C(create_on_missing), hence when set to C(true), the module will
+        always fail if the UCS is missing, even if C(create_on_missing) option is set to C(true).
+      - When set to C(false), with C(create_on_missing) set to C(false) the module will return no change
+        if the ucs file is missing on device.
     type: bool
-    default: no
+    default: false
   force:
     description:
-      - If C(no), the file is only transferred if the destination does not
+      - If C(false), the file is only transferred if the destination does not
         exist.
     type: bool
-    default: yes
+    default: true
   src:
     description:
       - The name of the UCS file to create on the remote server for downloading.
       - The file is retrieved or created in /var/local/ucs/.
-      - This option is mandatory when C(only_create_file) is set to C(yes).
+      - This option is mandatory when C(only_create_file) is set to C(true).
     type: str
   async_timeout:
     description:
       - Parameter used when creating new UCS file on a device.
-      - The amount of time to wait for the API async interface to complete its task, in seconds.
+      - The number of seconds to wait for the API async interface to complete its task.
       - The accepted value range is between C(150) and C(1800) seconds.
     type: int
     default: 150
   only_create_file:
     description:
-      - If C(yes), the file is created on device and not downloaded. If the UCS archive exists on device,
-        no change is made and file is not be downloaded.
-      - To recreate UCS files left on the device, remove them with C(bigip_ucs) module before running this module with
-        C(only_create_file) set to C(yes).
+      - If C(true), the file is created on the device and not downloaded. If the UCS archive exists on the device,
+        no change is made and the file is not downloaded.
+      - To recreate UCS files left on the device, remove them with the C(bigip_ucs) module before running this
+        module with C(only_create_file) set to C(true).
     type: bool
-    default: no
+    default: false
     version_added: "1.12.0"
 notes:
   - BIG-IP provides no way to get a checksum of the UCS files on the system
@@ -84,7 +90,9 @@ notes:
     https://clouddocs.f5.com/products/orchestration/ansible/devel/usage/module-usage-with-tower.html
   - Some longer running tasks might cause the REST interface on BIG-IP to time out, to avoid this adjust the timers as
     per this KB article https://support.f5.com/csp/article/K94602685
-extends_documentation_fragment: f5networks.f5_modules.f5
+extends_documentation_fragment:
+  - f5networks.f5_modules.f5
+  - ansible.builtin.files
 author:
   - Tim Rupp (@caphrim007)
   - Wojciech Wypior (@wojtek0806)
@@ -139,7 +147,7 @@ checksum:
   type: str
   sample: 7b46bbe4f8ebfee64761b5313855618f64c64109
 dest:
-  description: Location on the ansible host the UCS was saved to.
+  description: Location on the Ansible host the UCS was saved to.
   returned: success
   type: str
   sample: /path/to/file.txt
@@ -196,11 +204,22 @@ import os
 import re
 import tempfile
 import time
-
+import traceback
 from datetime import datetime
-from distutils.version import LooseVersion
 
-from ansible.module_utils.basic import AnsibleModule
+try:
+    from packaging.version import Version
+except ImportError:
+    HAS_PACKAGING = False
+    Version = None
+    PACKAGING_IMPORT_ERROR = traceback.format_exc()
+else:
+    HAS_PACKAGING = True
+    PACKAGING_IMPORT_ERROR = None
+
+from ansible.module_utils.basic import (
+    AnsibleModule, missing_required_lib
+)
 
 from ..module_utils.bigip import F5RestClient
 from ..module_utils.common import (
@@ -219,10 +238,13 @@ class Parameters(AnsibleF5Parameters):
         'src',
         'md5sum',
         'checksum',
-        'backup_file']
+        'backup_file'
+    ]
     api_attributes = []
     api_map = {}
 
+
+class ModuleParameters(Parameters):
     @property
     def options(self):
         result = []
@@ -254,14 +276,14 @@ class Parameters(AnsibleF5Parameters):
                     # circumstances where the directory does not have
                     # the execute bit for the current user set, in
                     # which case the stat() call will raise an OSError
-                    os.stat(os.path.dirname(result))
+                    os.stat(os.path.dirname(self.dest))
                 except OSError as e:
                     if "permission denied" in str(e).lower():
                         raise F5ModuleError(
-                            "Destination directory {0} is not accessible".format(os.path.dirname(result))
+                            "Destination directory {0} is not accessible".format(os.path.dirname(self.dest))
                         )
                     raise F5ModuleError(
-                        "Destination directory {0} does not exist".format(os.path.dirname(result))
+                        "Destination directory {0} does not exist".format(os.path.dirname(self.dest))
                     )
 
         if not os.access(os.path.dirname(result), os.W_OK):
@@ -334,7 +356,7 @@ class ModuleManager(object):
         :return: bool
         """
         version = tmos_version(self.client)
-        if LooseVersion(version) < LooseVersion('12.1.0'):
+        if Version(version) < Version('12.1.0'):
             return True
         else:
             return False
@@ -344,7 +366,7 @@ class BaseManager(object):
     def __init__(self, *args, **kwargs):
         self.module = kwargs.get('module', None)
         self.client = F5RestClient(**self.module.params)
-        self.want = Parameters(params=self.module.params)
+        self.want = ModuleParameters(params=self.module.params)
         self.changes = UsableChanges()
 
     def exec_module(self):
@@ -392,6 +414,9 @@ class BaseManager(object):
             )
         self._set_checksum()
         self._set_md5sum()
+        self.changes.update({'src': self.want.src})
+        self.changes.update({'md5sum': self.want.md5sum})
+        self.changes.update({'checksum': self.want.checksum})
         file_args = self.module.load_file_common_arguments(self.module.params)
         return self.module.set_fs_attributes_if_different(file_args, True)
 
@@ -434,7 +459,7 @@ class BaseManager(object):
         self.async_wait(task)
 
     def create_async_task_on_device(self):
-        if self.want.passphrase:
+        if self.want.encryption_password:
             params = dict(
                 command='save',
                 name=self.want.src,
@@ -721,6 +746,12 @@ def main():
         add_file_common_args=spec.add_file_common_args
     )
 
+    if not HAS_PACKAGING:
+        module.fail_json(
+            msg=missing_required_lib('packaging'),
+            exception=PACKAGING_IMPORT_ERROR
+        )
+
     try:
         mm = ModuleManager(module=module)
         results = mm.exec_module()
