@@ -1,14 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright: (c) 2020, Hetzner Cloud GmbH <info@hetzner-cloud.de>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import absolute_import, division, print_function
 
-__metaclass__ = type
-
-DOCUMENTATION = '''
+DOCUMENTATION = """
 ---
 module: hcloud_certificate_info
 short_description: Gather infos about your Hetzner Cloud certificates.
@@ -20,6 +16,7 @@ options:
     id:
         description:
             - The ID of the certificate you want to get.
+            - The module will fail if the provided ID is invalid.
         type: int
     name:
         description:
@@ -32,11 +29,11 @@ options:
 extends_documentation_fragment:
 - hetzner.hcloud.hcloud
 
-'''
+"""
 
 EXAMPLES = """
 - name: Gather hcloud certificate infos
-  hcloud_certificate_info:
+  hetzner.hcloud.hcloud_certificate_info:
   register: output
 - name: Print the gathered infos
   debug:
@@ -86,80 +83,77 @@ hcloud_certificate_info:
             returned: always
             type: dict
 """
+from typing import List, Optional
+
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
-from ansible_collections.hetzner.hcloud.plugins.module_utils.hcloud import Hcloud
+from ansible.module_utils.common.text.converters import to_native
 
-try:
-    from hcloud import APIException
-except ImportError:
-    pass
+from ..module_utils.hcloud import AnsibleHCloud
+from ..module_utils.vendor.hcloud import HCloudException
+from ..module_utils.vendor.hcloud.certificates import BoundCertificate
 
 
-class AnsibleHcloudCertificateInfo(Hcloud):
-    def __init__(self, module):
-        Hcloud.__init__(self, module, "hcloud_certificate_info")
-        self.hcloud_certificate_info = None
+class AnsibleHCloudCertificateInfo(AnsibleHCloud):
+    represent = "hcloud_certificate_info"
+
+    hcloud_certificate_info: Optional[List[BoundCertificate]] = None
 
     def _prepare_result(self):
         certificates = []
 
         for certificate in self.hcloud_certificate_info:
             if certificate:
-                certificates.append({
-                    "id": to_native(certificate.id),
-                    "name": to_native(certificate.name),
-                    "fingerprint": to_native(certificate.fingerprint),
-                    "certificate": to_native(certificate.certificate),
-                    "not_valid_before": to_native(certificate.not_valid_before),
-                    "not_valid_after": to_native(certificate.not_valid_after),
-                    "domain_names": [to_native(domain) for domain in certificate.domain_names],
-                    "labels": certificate.labels
-                })
+                certificates.append(
+                    {
+                        "id": to_native(certificate.id),
+                        "name": to_native(certificate.name),
+                        "fingerprint": to_native(certificate.fingerprint),
+                        "certificate": to_native(certificate.certificate),
+                        "not_valid_before": to_native(certificate.not_valid_before),
+                        "not_valid_after": to_native(certificate.not_valid_after),
+                        "domain_names": [to_native(domain) for domain in certificate.domain_names],
+                        "labels": certificate.labels,
+                    }
+                )
         return certificates
 
     def get_certificates(self):
         try:
             if self.module.params.get("id") is not None:
-                self.hcloud_certificate_info = [self.client.certificates.get_by_id(
-                    self.module.params.get("id")
-                )]
+                self.hcloud_certificate_info = [self.client.certificates.get_by_id(self.module.params.get("id"))]
             elif self.module.params.get("name") is not None:
-                self.hcloud_certificate_info = [self.client.certificates.get_by_name(
-                    self.module.params.get("name")
-                )]
+                self.hcloud_certificate_info = [self.client.certificates.get_by_name(self.module.params.get("name"))]
             elif self.module.params.get("label_selector") is not None:
                 self.hcloud_certificate_info = self.client.certificates.get_all(
-                    label_selector=self.module.params.get("label_selector"))
+                    label_selector=self.module.params.get("label_selector")
+                )
             else:
                 self.hcloud_certificate_info = self.client.certificates.get_all()
 
-        except APIException as e:
-            self.module.fail_json(msg=e.message)
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
 
-    @staticmethod
-    def define_module():
+    @classmethod
+    def define_module(cls):
         return AnsibleModule(
             argument_spec=dict(
                 id={"type": "int"},
                 name={"type": "str"},
                 label_selector={"type": "str"},
-                **Hcloud.base_module_arguments()
+                **super().base_module_arguments()
             ),
             supports_check_mode=True,
         )
 
 
 def main():
-    module = AnsibleHcloudCertificateInfo.define_module()
+    module = AnsibleHCloudCertificateInfo.define_module()
+    hcloud = AnsibleHCloudCertificateInfo(module)
 
-    hcloud = AnsibleHcloudCertificateInfo(module)
     hcloud.get_certificates()
     result = hcloud.get_result()
 
-    ansible_info = {
-        'hcloud_certificate_info': result['hcloud_certificate_info']
-    }
+    ansible_info = {"hcloud_certificate_info": result["hcloud_certificate_info"]}
     module.exit_json(**ansible_info)
 
 
