@@ -1,20 +1,15 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright: (c) 2020, Hetzner Cloud GmbH <info@hetzner-cloud.de>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import absolute_import, division, print_function
 
-__metaclass__ = type
-
-DOCUMENTATION = '''
+DOCUMENTATION = """
 ---
 module: hcloud_load_balancer
 
 short_description: Create and manage cloud Load Balancers on the Hetzner Cloud.
 
-
 description:
     - Create, update and manage cloud Load Balancers on the Hetzner Cloud.
 
@@ -30,22 +25,28 @@ options:
     name:
         description:
             - The Name of the Hetzner Cloud Load Balancer to manage.
-            - Only required if no Load Balancer I(id) is given or a Load Balancer does not exists.
+            - Only required if no Load Balancer I(id) is given or a Load Balancer does not exist.
         type: str
     load_balancer_type:
         description:
             - The Load Balancer Type of the Hetzner Cloud Load Balancer to manage.
-            - Required if Load Balancer does not exists.
+            - Required if Load Balancer does not exist.
         type: str
+    algorithm:
+        description:
+            - Algorithm of the Load Balancer.
+        type: str
+        default: round_robin
+        choices: [round_robin, least_connections]
     location:
         description:
             - Location of Load Balancer.
-            - Required if no I(network_zone) is given and Load Balancer does not exists.
+            - Required if no I(network_zone) is given and Load Balancer does not exist.
         type: str
     network_zone:
         description:
             - Network Zone of Load Balancer.
-            - Required of no I(location) is given and Load Balancer does not exists.
+            - Required of no I(location) is given and Load Balancer does not exist.
         type: str
     labels:
         description:
@@ -71,21 +72,21 @@ extends_documentation_fragment:
 
 requirements:
   - hcloud-python >= 1.8.0
-'''
+"""
 
 EXAMPLES = """
 - name: Create a basic Load Balancer
-  hcloud_load_balancer:
+  hetzner.hcloud.hcloud_load_balancer:
     name: my-Load Balancer
     load_balancer_type: lb11
+    algorithm: round_robin
     location: fsn1
     state: present
 
 - name: Ensure the Load Balancer is absent (remove if needed)
-  hcloud_load_balancer:
+  hetzner.hcloud.hcloud_load_balancer:
     name: my-Load Balancer
     state: absent
-
 """
 
 RETURN = """
@@ -114,6 +115,12 @@ hcloud_load_balancer:
             returned: always
             type: str
             sample: cx11
+        algorithm:
+            description: Algorithm of the Load Balancer.
+            returned: always
+            type: str
+            choices: [round_robin, least_connections]
+            sample: round_robin
         ipv4_address:
             description: Public IPv4 address of the Load Balancer
             returned: always
@@ -145,25 +152,30 @@ hcloud_load_balancer:
             sample: false
 """
 
+from typing import Optional
+
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
-from ansible_collections.hetzner.hcloud.plugins.module_utils.hcloud import Hcloud
+from ansible.module_utils.common.text.converters import to_native
 
-try:
-    from hcloud.load_balancers.domain import LoadBalancer
-    from hcloud import APIException
-except ImportError:
-    APIException = None
+from ..module_utils.hcloud import AnsibleHCloud
+from ..module_utils.vendor.hcloud import HCloudException
+from ..module_utils.vendor.hcloud.load_balancers import (
+    BoundLoadBalancer,
+    LoadBalancerAlgorithm,
+)
 
 
-class AnsibleHcloudLoadBalancer(Hcloud):
-    def __init__(self, module):
-        Hcloud.__init__(self, module, "hcloud_load_balancer")
-        self.hcloud_load_balancer = None
+class AnsibleHCloudLoadBalancer(AnsibleHCloud):
+    represent = "hcloud_load_balancer"
+
+    hcloud_load_balancer: Optional[BoundLoadBalancer] = None
 
     def _prepare_result(self):
-        private_ipv4_address = None if len(self.hcloud_load_balancer.private_net) == 0 else to_native(
-            self.hcloud_load_balancer.private_net[0].ip)
+        private_ipv4_address = (
+            None
+            if len(self.hcloud_load_balancer.private_net) == 0
+            else to_native(self.hcloud_load_balancer.private_net[0].ip)
+        )
         return {
             "id": to_native(self.hcloud_load_balancer.id),
             "name": to_native(self.hcloud_load_balancer.name),
@@ -171,6 +183,7 @@ class AnsibleHcloudLoadBalancer(Hcloud):
             "ipv6_address": to_native(self.hcloud_load_balancer.public_net.ipv6.ip),
             "private_ipv4_address": private_ipv4_address,
             "load_balancer_type": to_native(self.hcloud_load_balancer.load_balancer_type.name),
+            "algorithm": to_native(self.hcloud_load_balancer.algorithm.type),
             "location": to_native(self.hcloud_load_balancer.location.name),
             "labels": self.hcloud_load_balancer.labels,
             "delete_protection": self.hcloud_load_balancer.protection["delete"],
@@ -180,48 +193,41 @@ class AnsibleHcloudLoadBalancer(Hcloud):
     def _get_load_balancer(self):
         try:
             if self.module.params.get("id") is not None:
-                self.hcloud_load_balancer = self.client.load_balancers.get_by_id(
-                    self.module.params.get("id")
-                )
+                self.hcloud_load_balancer = self.client.load_balancers.get_by_id(self.module.params.get("id"))
             else:
-                self.hcloud_load_balancer = self.client.load_balancers.get_by_name(
-                    self.module.params.get("name")
-                )
-        except APIException as e:
-            self.module.fail_json(msg=e.message)
+                self.hcloud_load_balancer = self.client.load_balancers.get_by_name(self.module.params.get("name"))
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
 
     def _create_load_balancer(self):
+        self.module.fail_on_missing_params(required_params=["name", "load_balancer_type"])
+        try:
+            params = {
+                "name": self.module.params.get("name"),
+                "algorithm": LoadBalancerAlgorithm(type=self.module.params.get("algorithm", "round_robin")),
+                "load_balancer_type": self.client.load_balancer_types.get_by_name(
+                    self.module.params.get("load_balancer_type")
+                ),
+                "labels": self.module.params.get("labels"),
+            }
 
-        self.module.fail_on_missing_params(
-            required_params=["name", "load_balancer_type"]
-        )
+            if self.module.params.get("location") is None and self.module.params.get("network_zone") is None:
+                self.module.fail_json(msg="one of the following is required: location, network_zone")
+            elif self.module.params.get("location") is not None and self.module.params.get("network_zone") is None:
+                params["location"] = self.client.locations.get_by_name(self.module.params.get("location"))
+            elif self.module.params.get("location") is None and self.module.params.get("network_zone") is not None:
+                params["network_zone"] = self.module.params.get("network_zone")
 
-        params = {
-            "name": self.module.params.get("name"),
-            "load_balancer_type": self.client.load_balancer_types.get_by_name(
-                self.module.params.get("load_balancer_type")
-            ),
-            "labels": self.module.params.get("labels"),
-        }
-
-        if self.module.params.get("location") is None and self.module.params.get("network_zone") is None:
-            self.module.fail_json(msg="one of the following is required: location, network_zone")
-        elif self.module.params.get("location") is not None and self.module.params.get("network_zone") is None:
-            params["location"] = self.client.locations.get_by_name(
-                self.module.params.get("location")
-            )
-        elif self.module.params.get("location") is None and self.module.params.get("network_zone") is not None:
-            params["network_zone"] = self.module.params.get("network_zone")
-
-        if not self.module.check_mode:
-            resp = self.client.load_balancers.create(**params)
-            resp.action.wait_until_finished(max_retries=1000)
-
-            delete_protection = self.module.params.get("delete_protection")
-            if delete_protection is not None:
-                self._get_load_balancer()
-                self.hcloud_load_balancer.change_protection(delete=delete_protection).wait_until_finished()
+            if not self.module.check_mode:
+                resp = self.client.load_balancers.create(**params)
+                resp.action.wait_until_finished(max_retries=1000)
 
+                delete_protection = self.module.params.get("delete_protection")
+                if delete_protection is not None:
+                    self._get_load_balancer()
+                    self.hcloud_load_balancer.change_protection(delete=delete_protection).wait_until_finished()
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
         self._mark_as_changed()
         self._get_load_balancer()
 
@@ -241,7 +247,9 @@ class AnsibleHcloudLoadBalancer(Hcloud):
             self._get_load_balancer()
 
             disable_public_interface = self.module.params.get("disable_public_interface")
-            if disable_public_interface is not None and disable_public_interface != (not self.hcloud_load_balancer.public_net.enabled):
+            if disable_public_interface is not None and disable_public_interface != (
+                not self.hcloud_load_balancer.public_net.enabled
+            ):
                 if not self.module.check_mode:
                     if disable_public_interface is True:
                         self.hcloud_load_balancer.disable_public_interface().wait_until_finished()
@@ -250,7 +258,10 @@ class AnsibleHcloudLoadBalancer(Hcloud):
                 self._mark_as_changed()
 
             load_balancer_type = self.module.params.get("load_balancer_type")
-            if load_balancer_type is not None and self.hcloud_load_balancer.load_balancer_type.name != load_balancer_type:
+            if (
+                load_balancer_type is not None
+                and self.hcloud_load_balancer.load_balancer_type.name != load_balancer_type
+            ):
                 new_load_balancer_type = self.client.load_balancer_types.get_by_name(load_balancer_type)
                 if not new_load_balancer_type:
                     self.module.fail_json(msg="unknown load balancer type")
@@ -260,9 +271,17 @@ class AnsibleHcloudLoadBalancer(Hcloud):
                     ).wait_until_finished(max_retries=1000)
 
                 self._mark_as_changed()
+
+            algorithm = self.module.params.get("algorithm")
+            if algorithm is not None and self.hcloud_load_balancer.algorithm.type != algorithm:
+                self.hcloud_load_balancer.change_algorithm(
+                    algorithm=LoadBalancerAlgorithm(type=algorithm)
+                ).wait_until_finished()
+                self._mark_as_changed()
+
             self._get_load_balancer()
-        except APIException as e:
-            self.module.fail_json(msg=e.message)
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
 
     def present_load_balancer(self):
         self._get_load_balancer()
@@ -279,16 +298,17 @@ class AnsibleHcloudLoadBalancer(Hcloud):
                     self.client.load_balancers.delete(self.hcloud_load_balancer)
                 self._mark_as_changed()
             self.hcloud_load_balancer = None
-        except APIException as e:
-            self.module.fail_json(msg=e.message)
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
 
-    @staticmethod
-    def define_module():
+    @classmethod
+    def define_module(cls):
         return AnsibleModule(
             argument_spec=dict(
                 id={"type": "int"},
                 name={"type": "str"},
                 load_balancer_type={"type": "str"},
+                algorithm={"choices": ["round_robin", "least_connections"], "default": "round_robin"},
                 location={"type": "str"},
                 network_zone={"type": "str"},
                 labels={"type": "dict"},
@@ -298,18 +318,18 @@ class AnsibleHcloudLoadBalancer(Hcloud):
                     "choices": ["absent", "present"],
                     "default": "present",
                 },
-                **Hcloud.base_module_arguments()
+                **super().base_module_arguments()
             ),
-            required_one_of=[['id', 'name']],
+            required_one_of=[["id", "name"]],
             mutually_exclusive=[["location", "network_zone"]],
             supports_check_mode=True,
         )
 
 
 def main():
-    module = AnsibleHcloudLoadBalancer.define_module()
+    module = AnsibleHCloudLoadBalancer.define_module()
 
-    hcloud = AnsibleHcloudLoadBalancer(module)
+    hcloud = AnsibleHCloudLoadBalancer(module)
     state = module.params.get("state")
     if state == "absent":
         hcloud.delete_load_balancer()
