@@ -1,14 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright: (c) 2020, Hetzner Cloud GmbH <info@hetzner-cloud.de>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import absolute_import, division, print_function
 
-__metaclass__ = type
-
-DOCUMENTATION = '''
+DOCUMENTATION = """
 ---
 module: hcloud_load_balancer_service
 
@@ -24,7 +20,7 @@ version_added: 0.1.0
 options:
     load_balancer:
         description:
-            - The Name of the Hetzner Cloud Load Balancer the service belongs to
+            - Name or ID of the Hetzner Cloud Load Balancer the service belongs to
         type: str
         required: true
     listen_port:
@@ -35,18 +31,19 @@ options:
     destination_port:
         description:
             - The port traffic is forwarded to, i.e. the port the targets are listening and accepting connections on.
-            - Required if services does not exists and protocol is tcp.
+            - Required if services does not exist and protocol is tcp.
         type: int
     protocol:
         description:
             - Protocol of the service.
-            - Required if Load Balancer does not exists.
+            - Required if Load Balancer does not exist.
         type: str
         choices: [ http, https, tcp ]
     proxyprotocol:
         description:
             - Enable the PROXY protocol.
         type: bool
+        default: False
     http:
         description:
             - Configuration for HTTP and HTTPS services
@@ -69,10 +66,12 @@ options:
                 description:
                     - Enable or disable sticky_sessions
                 type: bool
+                default: False
             redirect_http:
                 description:
                     - Redirect Traffic from Port 80 to Port 443, only available if protocol is https
                 type: bool
+                default: False
     health_check:
         description:
             - Configuration for health checks
@@ -125,6 +124,7 @@ options:
                         description:
                             - Verify the TLS certificate, only available if health check protocol is https
                         type: bool
+                        default: False
     state:
         description:
             - State of the Load Balancer.
@@ -136,18 +136,18 @@ extends_documentation_fragment:
 
 requirements:
   - hcloud-python >= 1.8.1
-'''
+"""
 
 EXAMPLES = """
 - name: Create a basic Load Balancer service with Port 80
-  hcloud_load_balancer_service:
+  hetzner.hcloud.hcloud_load_balancer_service:
     load_balancer: my-load-balancer
     protocol: http
     listen_port: 80
     state: present
 
 - name: Ensure the Load Balancer is absent (remove if needed)
-  hcloud_load_balancer_service:
+  hetzner.hcloud.hcloud_load_balancer_service:
     load_balancer: my-Load Balancer
     protocol: http
     listen_port: 80
@@ -279,23 +279,27 @@ hcloud_load_balancer_service:
                             sample: false
 """
 
+from typing import Optional
+
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
-from ansible_collections.hetzner.hcloud.plugins.module_utils.hcloud import Hcloud
+from ansible.module_utils.common.text.converters import to_native
 
-try:
-    from hcloud.load_balancers.domain import LoadBalancer, LoadBalancerService, LoadBalancerServiceHttp, \
-        LoadBalancerServiceHealthCheck, LoadBalancerServiceHealthCheckHttp
-    from hcloud import APIException
-except ImportError:
-    APIException = None
+from ..module_utils.hcloud import AnsibleHCloud
+from ..module_utils.vendor.hcloud import APIException, HCloudException
+from ..module_utils.vendor.hcloud.load_balancers import (
+    BoundLoadBalancer,
+    LoadBalancerHealtCheckHttp,
+    LoadBalancerHealthCheck,
+    LoadBalancerService,
+    LoadBalancerServiceHttp,
+)
 
 
-class AnsibleHcloudLoadBalancerService(Hcloud):
-    def __init__(self, module):
-        Hcloud.__init__(self, module, "hcloud_load_balancer_service")
-        self.hcloud_load_balancer = None
-        self.hcloud_load_balancer_service = None
+class AnsibleHCloudLoadBalancerService(AnsibleHCloud):
+    represent = "hcloud_load_balancer_service"
+
+    hcloud_load_balancer: Optional[BoundLoadBalancer] = None
+    hcloud_load_balancer_service: Optional[LoadBalancerService] = None
 
     def _prepare_result(self):
         http = None
@@ -305,8 +309,9 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
                 "cookie_lifetime": self.hcloud_load_balancer_service.http.cookie_name,
                 "redirect_http": self.hcloud_load_balancer_service.http.redirect_http,
                 "sticky_sessions": self.hcloud_load_balancer_service.http.sticky_sessions,
-                "certificates": [to_native(certificate.name) for certificate in
-                                 self.hcloud_load_balancer_service.http.certificates],
+                "certificates": [
+                    to_native(certificate.name) for certificate in self.hcloud_load_balancer_service.http.certificates
+                ],
             }
         health_check = {
             "protocol": to_native(self.hcloud_load_balancer_service.health_check.protocol),
@@ -320,8 +325,10 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
                 "domain": to_native(self.hcloud_load_balancer_service.health_check.http.domain),
                 "path": to_native(self.hcloud_load_balancer_service.health_check.http.path),
                 "response": to_native(self.hcloud_load_balancer_service.health_check.http.response),
-                "certificates": [to_native(status_code) for status_code in
-                                 self.hcloud_load_balancer_service.health_check.http.status_codes],
+                "status_codes": [
+                    to_native(status_code)
+                    for status_code in self.hcloud_load_balancer_service.health_check.http.status_codes
+                ],
                 "tls": self.hcloud_load_balancer_service.health_check.http.tls,
             }
         return {
@@ -336,27 +343,23 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
 
     def _get_load_balancer(self):
         try:
-            self.hcloud_load_balancer = self.client.load_balancers.get_by_name(
-                self.module.params.get("load_balancer")
+            self.hcloud_load_balancer = self._client_get_by_name_or_id(
+                "load_balancers",
+                self.module.params.get("load_balancer"),
             )
             self._get_load_balancer_service()
-        except APIException as e:
-            self.module.fail_json(msg=e.message)
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
 
     def _create_load_balancer_service(self):
-
-        self.module.fail_on_missing_params(
-            required_params=["protocol"]
-        )
+        self.module.fail_on_missing_params(required_params=["protocol"])
         if self.module.params.get("protocol") == "tcp":
-            self.module.fail_on_missing_params(
-                required_params=["destination_port"]
-            )
+            self.module.fail_on_missing_params(required_params=["destination_port"])
 
         params = {
             "protocol": self.module.params.get("protocol"),
             "listen_port": self.module.params.get("listen_port"),
-            "proxyprotocol": self.module.params.get("proxyprotocol")
+            "proxyprotocol": self.module.params.get("proxyprotocol"),
         }
 
         if self.module.params.get("destination_port"):
@@ -367,14 +370,16 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
 
         if self.module.params.get("health_check"):
             params["health_check"] = self.__get_service_health_checks(
-                health_check=self.module.params.get("health_check"))
+                health_check=self.module.params.get("health_check")
+            )
 
         if not self.module.check_mode:
             try:
                 self.hcloud_load_balancer.add_service(LoadBalancerService(**params)).wait_until_finished(
-                    max_retries=1000)
-            except APIException as e:
-                self.module.fail_json(msg=e.message)
+                    max_retries=1000
+                )
+            except HCloudException as exception:
+                self.fail_json_hcloud(exception)
         self._mark_as_changed()
         self._get_load_balancer()
         self._get_load_balancer_service()
@@ -396,21 +401,17 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
                     hcloud_cert = None
                     try:
                         try:
-                            hcloud_cert = self.client.certificates.get_by_name(
-                                certificate
-                            )
-                        except APIException:
-                            hcloud_cert = self.client.certificates.get_by_id(
-                                certificate
-                            )
-                    except APIException as e:
-                        self.module.fail_json(msg=e.message)
+                            hcloud_cert = self.client.certificates.get_by_name(certificate)
+                        except Exception:
+                            hcloud_cert = self.client.certificates.get_by_id(certificate)
+                    except HCloudException as exception:
+                        self.fail_json_hcloud(exception)
                     service_http.certificates.append(hcloud_cert)
 
         return service_http
 
     def __get_service_health_checks(self, health_check):
-        service_health_check = LoadBalancerServiceHealthCheck()
+        service_health_check = LoadBalancerHealthCheck()
         if health_check.get("protocol") is not None:
             service_health_check.protocol = health_check.get("protocol")
         if health_check.get("port") is not None:
@@ -423,7 +424,7 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
             service_health_check.retries = health_check.get("retries")
         if health_check.get("http") is not None:
             health_check_http = health_check.get("http")
-            service_health_check.http = LoadBalancerServiceHealthCheckHttp()
+            service_health_check.http = LoadBalancerHealtCheckHttp()
             if health_check_http.get("domain") is not None:
                 service_health_check.http.domain = health_check_http.get("domain")
             if health_check_http.get("path") is not None:
@@ -465,14 +466,16 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
 
             if self.module.params.get("health_check") is not None:
                 params["health_check"] = self.__get_service_health_checks(
-                    health_check=self.module.params.get("health_check"))
+                    health_check=self.module.params.get("health_check")
+                )
                 changed = True
 
             if not self.module.check_mode:
                 self.hcloud_load_balancer.update_service(LoadBalancerService(**params)).wait_until_finished(
-                    max_retries=1000)
-        except APIException as e:
-            self.module.fail_json(msg=e.message)
+                    max_retries=1000
+                )
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
         self._get_load_balancer()
 
         if changed:
@@ -495,15 +498,19 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
             self._get_load_balancer()
             if self.hcloud_load_balancer_service is not None:
                 if not self.module.check_mode:
-                    self.hcloud_load_balancer.delete_service(self.hcloud_load_balancer_service).wait_until_finished(
-                        max_retries=1000)
+                    try:
+                        self.hcloud_load_balancer.delete_service(self.hcloud_load_balancer_service).wait_until_finished(
+                            max_retries=1000
+                        )
+                    except HCloudException as exception:
+                        self.fail_json_hcloud(exception)
                 self._mark_as_changed()
             self.hcloud_load_balancer_service = None
-        except APIException as e:
-            self.module.fail_json(msg=e.message)
+        except APIException as exception:
+            self.fail_json_hcloud(exception)
 
-    @staticmethod
-    def define_module():
+    @classmethod
+    def define_module(cls):
         return AnsibleModule(
             argument_spec=dict(
                 load_balancer={"type": "str", "required": True},
@@ -517,26 +524,12 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
                 http={
                     "type": "dict",
                     "options": dict(
-                        cookie_name={
-                            "type": "str"
-                        },
-                        cookie_lifetime={
-                            "type": "int"
-                        },
-                        sticky_sessions={
-                            "type": "bool",
-                            "default": False
-                        },
-                        redirect_http={
-                            "type": "bool",
-                            "default": False
-                        },
-                        certificates={
-                            "type": "list",
-                            "elements": "str"
-                        },
-
-                    )
+                        cookie_name={"type": "str"},
+                        cookie_lifetime={"type": "int"},
+                        sticky_sessions={"type": "bool", "default": False},
+                        redirect_http={"type": "bool", "default": False},
+                        certificates={"type": "list", "elements": "str"},
+                    ),
                 },
                 health_check={
                     "type": "dict",
@@ -545,57 +538,36 @@ class AnsibleHcloudLoadBalancerService(Hcloud):
                             "type": "str",
                             "choices": ["http", "https", "tcp"],
                         },
-                        port={
-                            "type": "int"
-                        },
-                        interval={
-                            "type": "int"
-                        },
-                        timeout={
-                            "type": "int"
-                        },
-                        retries={
-                            "type": "int"
-                        },
+                        port={"type": "int"},
+                        interval={"type": "int"},
+                        timeout={"type": "int"},
+                        retries={"type": "int"},
                         http={
                             "type": "dict",
                             "options": dict(
-                                domain={
-                                    "type": "str"
-                                },
-                                path={
-                                    "type": "str"
-                                },
-                                response={
-                                    "type": "str"
-                                },
-                                status_codes={
-                                    "type": "list",
-                                    "elements": "str"
-                                },
-                                tls={
-                                    "type": "bool",
-                                    "default": False
-                                },
-                            )
-                        }
-                    )
-
+                                domain={"type": "str"},
+                                path={"type": "str"},
+                                response={"type": "str"},
+                                status_codes={"type": "list", "elements": "str"},
+                                tls={"type": "bool", "default": False},
+                            ),
+                        },
+                    ),
                 },
                 state={
                     "choices": ["absent", "present"],
                     "default": "present",
                 },
-                **Hcloud.base_module_arguments()
+                **super().base_module_arguments(),
             ),
             supports_check_mode=True,
         )
 
 
 def main():
-    module = AnsibleHcloudLoadBalancerService.define_module()
+    module = AnsibleHCloudLoadBalancerService.define_module()
 
-    hcloud = AnsibleHcloudLoadBalancerService(module)
+    hcloud = AnsibleHCloudLoadBalancerService(module)
     state = module.params.get("state")
     if state == "absent":
         hcloud.delete_load_balancer_service()
