@@ -64,13 +64,13 @@ extends_documentation_fragment:
 
 EXAMPLES = """
 - name: Create a basic network
-  hcloud_network:
+  hetzner.hcloud.hcloud_network:
     name: my-network
     ip_range: 10.0.0.0/8
     state: present
 
 - name: Ensure the Network is absent (remove if needed)
-  hcloud_network:
+  hetzner.hcloud.hcloud_network:
     name: my-network
     state: absent
 """
@@ -116,15 +116,20 @@ hcloud_network:
                 mylabel: 123
 """
 
+from typing import Optional
+
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.common.text.converters import to_native
-from ansible_collections.hetzner.hcloud.plugins.module_utils.hcloud import Hcloud
+
+from ..module_utils.hcloud import AnsibleHCloud
+from ..module_utils.vendor.hcloud import HCloudException
+from ..module_utils.vendor.hcloud.networks import BoundNetwork
 
 
-class AnsibleHcloudNetwork(Hcloud):
-    def __init__(self, module):
-        Hcloud.__init__(self, module, "hcloud_network")
-        self.hcloud_network = None
+class AnsibleHCloudNetwork(AnsibleHCloud):
+    represent = "hcloud_network"
+
+    hcloud_network: Optional[BoundNetwork] = None
 
     def _prepare_result(self):
         return {
@@ -142,8 +147,8 @@ class AnsibleHcloudNetwork(Hcloud):
                 self.hcloud_network = self.client.networks.get_by_id(self.module.params.get("id"))
             else:
                 self.hcloud_network = self.client.networks.get_by_name(self.module.params.get("name"))
-        except Exception as e:
-            self.module.fail_json(msg=e.message)
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
 
     def _create_network(self):
         self.module.fail_on_missing_params(required_params=["name", "ip_range"])
@@ -165,8 +170,8 @@ class AnsibleHcloudNetwork(Hcloud):
                 if delete_protection is not None:
                     self._get_network()
                     self.hcloud_network.change_protection(delete=delete_protection).wait_until_finished()
-        except Exception as e:
-            self.module.fail_json(msg=e.message)
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
         self._mark_as_changed()
         self._get_network()
 
@@ -198,8 +203,8 @@ class AnsibleHcloudNetwork(Hcloud):
                 if not self.module.check_mode:
                     self.hcloud_network.change_protection(delete=delete_protection).wait_until_finished()
                 self._mark_as_changed()
-        except Exception as e:
-            self.module.fail_json(msg=e.message)
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
         self._get_network()
 
     def present_network(self):
@@ -216,12 +221,12 @@ class AnsibleHcloudNetwork(Hcloud):
                 if not self.module.check_mode:
                     self.client.networks.delete(self.hcloud_network)
                 self._mark_as_changed()
-        except Exception as e:
-            self.module.fail_json(msg=e.message)
+        except HCloudException as exception:
+            self.fail_json_hcloud(exception)
         self.hcloud_network = None
 
-    @staticmethod
-    def define_module():
+    @classmethod
+    def define_module(cls):
         return AnsibleModule(
             argument_spec=dict(
                 id={"type": "int"},
@@ -234,7 +239,7 @@ class AnsibleHcloudNetwork(Hcloud):
                     "choices": ["absent", "present"],
                     "default": "present",
                 },
-                **Hcloud.base_module_arguments()
+                **super().base_module_arguments()
             ),
             required_one_of=[["id", "name"]],
             supports_check_mode=True,
@@ -242,9 +247,9 @@ class AnsibleHcloudNetwork(Hcloud):
 
 
 def main():
-    module = AnsibleHcloudNetwork.define_module()
+    module = AnsibleHCloudNetwork.define_module()
 
-    hcloud = AnsibleHcloudNetwork(module)
+    hcloud = AnsibleHCloudNetwork(module)
     state = module.params["state"]
     if state == "absent":
         hcloud.delete_network()
