@@ -66,6 +66,15 @@ options:
     type: str
     description:
     - Sets the password of the bind_user user name account.
+  force_bind_password:
+    type: bool
+    default: true
+    description:
+    - Will force the bind password to be reset even if the bind user password
+      is unchanged.
+    - If set to I(false) and I(bind_user) is unchanged the password will not
+      be reset.
+    version_added: 1.14.0
   bind_user:
     type: str
     description:
@@ -84,7 +93,8 @@ options:
       specify OU= for each OU and multiple OUs should be separated by commas.
       The order of OUs is important and should get larger in scope from left
       to right. Each OU should not exceed 64 characters in length.
-    - Not Supported from Purity 5.2.0 or higher. Use I(purefa_dsrole) module.
+    - Not Supported from Purity 5.2.0 or higher.
+      Use I(purestorage.flasharray.purefa_dsrole) module.
   ro_group:
     type: str
     description:
@@ -92,7 +102,8 @@ options:
       containing users with read-only privileges on the FlashArray. This
       name should be just the Common Name of the group without the CN=
       specifier. Common Names should not exceed 64 characters in length.
-    - Not Supported from Purity 5.2.0 or higher. Use I(purefa_dsrole) module.
+    - Not Supported from Purity 5.2.0 or higher.
+      Use I(purestorage.flasharray.purefa_dsrole) module.
   sa_group:
     type: str
     description:
@@ -101,7 +112,8 @@ options:
       FlashArray. This name should be just the Common Name of the group
       without the CN= specifier. Common Names should not exceed 64
       characters in length.
-    - Not Supported from Purity 5.2.0 or higher. Use I(purefa_dsrole) module.
+    - Not Supported from Purity 5.2.0 or higher.
+      Use I(purestorage.flasharray.purefa_dsrole) module.
   aa_group:
     type: str
     description:
@@ -109,7 +121,8 @@ options:
       administrators with full privileges when managing the FlashArray.
       The name should be just the Common Name of the group without the
       CN= specifier. Common Names should not exceed 64 characters in length.
-    - Not Supported from Purity 5.2.0 or higher. Use I(purefa_dsrole) module.
+    - Not Supported from Purity 5.2.0 or higher.
+      Use I(purestorage.flasharray.purefa_dsrole) module.
   user_login:
     type: str
     description:
@@ -132,13 +145,13 @@ extends_documentation_fragment:
 
 EXAMPLES = r"""
 - name: Delete existing directory service
-  purefa_ds:
+  purestorage.flasharray.purefa_ds:
     state: absent
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
 - name: Create directory service (disabled) - Pre-5.2.0
-  purefa_ds:
+  purestorage.flasharray.purefa_ds:
     uri: "ldap://lab.purestorage.com"
     base_dn: "DC=lab,DC=purestorage,DC=com"
     bind_user: Administrator
@@ -151,7 +164,7 @@ EXAMPLES = r"""
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
 - name: Create directory service (disabled) - 5.2.0 or higher
-  purefa_ds:
+  purestorage.flasharray.purefa_ds:
     dstype: management
     uri: "ldap://lab.purestorage.com"
     base_dn: "DC=lab,DC=purestorage,DC=com"
@@ -161,19 +174,19 @@ EXAMPLES = r"""
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
 - name: Enable existing directory service
-  purefa_ds:
+  purestorage.flasharray.purefa_ds:
     enable: true
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
 - name: Disable existing directory service
-  purefa_ds:
+  purestorage.flasharray.purefa_ds:
     enable: false
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
 - name: Create directory service (enabled) - Pre-5.2.0
-  purefa_ds:
+  purestorage.flasharray.purefa_ds:
     enable: true
     uri: "ldap://lab.purestorage.com"
     base_dn: "DC=lab,DC=purestorage,DC=com"
@@ -187,7 +200,7 @@ EXAMPLES = r"""
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
 - name: Create directory service (enabled) - 5.2.0 or higher
-  purefa_ds:
+  purestorage.flasharray.purefa_ds:
     enable: true
     dstype: management
     uri: "ldap://lab.purestorage.com"
@@ -292,7 +305,7 @@ def delete_ds(module, array):
 def delete_ds_v6(module, array):
     """Delete Directory Service"""
     changed = True
-    if module.params("dstype") == "management":
+    if module.params["dstype"] == "management":
         management = flasharray.DirectoryServiceManagement(
             user_login_attribute="", user_object_class=""
         )
@@ -302,7 +315,7 @@ def delete_ds_v6(module, array):
             bind_user="",
             bind_password="",
             enabled=False,
-            services=module.params("dstype"),
+            services=module.params["dstype"],
             management=management,
         )
     else:
@@ -312,7 +325,7 @@ def delete_ds_v6(module, array):
             bind_user="",
             bind_password="",
             enabled=False,
-            services=module.params("dstype"),
+            services=module.params["dstype"],
         )
     if not module.check_mode:
         res = array.patch_directory_services(
@@ -402,7 +415,7 @@ def update_ds_v6(module, array):
         ).items
     )[0]
     current_ds = dirserv
-    if current_ds.uris is None or module.params["bind_password"] is not None:
+    if module.params["uri"] and current_ds.uris is None:
         password_required = True
     if current_ds.uris != module.params["uri"]:
         uris = module.params["uri"]
@@ -420,19 +433,23 @@ def update_ds_v6(module, array):
     if module.params["base_dn"] != "" and module.params["base_dn"] != base_dn:
         base_dn = module.params["base_dn"]
         ds_change = True
-    if module.params["bind_user"] != "" and module.params["bind_user"] != bind_user:
-        bind_user = module.params["bind_user"]
-        password_required = True
-        ds_change = True
-    if module.params["bind_password"] is not None:
-        bind_password = module.params["bind_password"]
-        ds_change = True
     if module.params["enable"] != current_ds.enabled:
         ds_change = True
+        if getattr(current_ds, "bind_password", None) is None:
+            password_required = True
+    if module.params["bind_user"] != "":
+        if module.params["bind_user"] != bind_user:
+            bind_user = module.params["bind_user"]
+            password_required = True
+            ds_change = True
+        elif module.params["force_bind_password"]:
+            password_required = True
+            ds_change = True
+    if module.params["bind_password"] is not None and password_required:
+        bind_password = module.params["bind_password"]
+        ds_change = True
     if password_required and not module.params["bind_password"]:
-        module.fail_json(
-            msg="'bind_password' must be provided with new/changed 'bind_user'"
-        )
+        module.fail_json(msg="'bind_password' must be provided for this task")
     if module.params["dstype"] == "management":
         try:
             user_login = current_ds.management.user_login_attribute
@@ -516,6 +533,7 @@ def main():
             uri=dict(type="list", elements="str"),
             state=dict(type="str", default="present", choices=["absent", "present"]),
             enable=dict(type="bool", default=False),
+            force_bind_password=dict(type="bool", default=True, no_log=True),
             bind_password=dict(type="str", no_log=True),
             bind_user=dict(type="str"),
             base_dn=dict(type="str"),
