@@ -42,7 +42,7 @@ options:
       Copy (added in 2.7) will create a full read/write clone of the
       snapshot.
     type: str
-    choices: [ absent, present, copy ]
+    choices: [ absent, present, copy, rename ]
     default: present
   eradicate:
     description:
@@ -64,6 +64,7 @@ options:
     description:
     - Volume to restore a specified volume to.
     - If not supplied this will default to the volume defined in I(restore)
+    - Name of new snapshot suffix if renaming a snapshot
     type: str
   offload:
     description:
@@ -85,6 +86,12 @@ options:
     - Force immeadiate snapshot to remote targets
     type: bool
     default: false
+  throttle:
+    description:
+    - If set to true, allows snapshot to fail if array health is not optimal.
+    type: bool
+    default: false
+    version_added: '1.21.0'
 extends_documentation_fragment:
 - purestorage.flasharray.purestorage.fa
 """
@@ -156,15 +163,34 @@ EXAMPLES = r"""
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
     state: absent
+
+- name: Rename protection group snapshot foo.fred to foo.dave
+  purestorage.flasharray.purefa_pgsnap:
+    name: foo
+    suffix: fred
+    target: dave
+    fa_url: 10.10.10.2
+    api_token: e31060a7-21fc-e277-6240-25983c6c4592
+    state: rename
 """
 
 RETURN = r"""
 """
 
+HAS_PURESTORAGE = True
+try:
+    from pypureclient.flasharray import (
+        ProtectionGroupSnapshot,
+        ProtectionGroupSnapshotPatch,
+    )
+except ImportError:
+    HAS_PURESTORAGE = False
+
 import re
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.purestorage.flasharray.plugins.module_utils.purefa import (
     get_system,
+    get_array,
     purefa_argument_spec,
 )
 
@@ -172,6 +198,7 @@ from datetime import datetime
 
 OFFLOAD_API = "1.16"
 POD_SNAPSHOT = "2.4"
+THROTTLE_API = "2.25"
 
 
 def _check_offload(module, array):
@@ -210,7 +237,7 @@ def get_pgroupvolume(module, array):
 
 
 def get_rpgsnapshot(module, array):
-    """Return iReplicated Snapshot or None"""
+    """Return Replicated Snapshot or None"""
     try:
         snapname = (
             module.params["name"]
@@ -252,31 +279,73 @@ def get_pgsnapshot(module, array):
 
 def create_pgsnapshot(module, array):
     """Create Protection Group Snapshot"""
+    api_version = array._list_available_rest_versions()
     changed = True
     if not module.check_mode:
-        try:
-            if (
-                module.params["now"]
-                and array.get_pgroup(module.params["name"])["targets"] is not None
-            ):
-                array.create_pgroup_snapshot(
-                    source=module.params["name"],
-                    suffix=module.params["suffix"],
-                    snap=True,
-                    apply_retention=module.params["apply_retention"],
-                    replicate_now=module.params["remote"],
+        if THROTTLE_API not in api_version:
+            try:
+                if array.get_pgroup(module.params["name"])["targets"] is not None:
+                    if module.params["now"]:
+                        array.create_pgroup_snapshot(
+                            source=module.params["name"],
+                            suffix=module.params["suffix"],
+                            snap=True,
+                            apply_retention=module.params["apply_retention"],
+                            replicate_now=True,
+                        )
+                    else:
+                        array.create_pgroup_snapshot(
+                            source=module.params["name"],
+                            suffix=module.params["suffix"],
+                            snap=True,
+                            apply_retention=module.params["apply_retention"],
+                            replicate=module.params["remote"],
+                        )
+                else:
+                    array.create_pgroup_snapshot(
+                        source=module.params["name"],
+                        suffix=module.params["suffix"],
+                        snap=True,
+                        apply_retention=module.params["apply_retention"],
+                    )
+            except Exception:
+                module.fail_json(
+                    msg="Snapshot of pgroup {0} failed.".format(module.params["name"])
                 )
+        else:
+            arrayv6 = get_array(module)
+            suffix = ProtectionGroupSnapshot(suffix=module.params["suffix"])
+            if array.get_pgroup(module.params["name"])["targets"] is not None:
+                if module.params["now"]:
+                    res = arrayv6.post_protection_group_snapshots(
+                        source_names=[module.params["name"]],
+                        apply_retention=module.params["apply_retention"],
+                        replicate_now=True,
+                        throttle=module.params["throttle"],
+                        protection_group_snapshot=suffix,
+                    )
+                else:
+                    res = arrayv6.post_protection_group_snapshots(
+                        source_names=[module.params["name"]],
+                        apply_retention=module.params["apply_retention"],
+                        throttle=module.params["throttle"],
+                        protection_group_snapshot=suffix,
+                        replicate=module.params["remote"],
+                    )
             else:
-                array.create_pgroup_snapshot(
-                    source=module.params["name"],
-                    suffix=module.params["suffix"],
-                    snap=True,
+                res = arrayv6.post_protection_group_snapshots(
+                    source_names=[module.params["name"]],
                     apply_retention=module.params["apply_retention"],
+                    throttle=module.params["throttle"],
+                    protection_group_snapshot=suffix,
+                )
+
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Snapshot of pgroup {0} failed. Error: {1}".format(
+                        module.params["name"], res.errors[0].message
+                    )
                 )
-        except Exception:
-            module.fail_json(
-                msg="Snapshot of pgroup {0} failed.".format(module.params["name"])
-            )
     module.exit_json(changed=changed)
 
 
@@ -408,6 +477,26 @@ def eradicate_pgsnapshot(module, array):
     module.exit_json(changed=changed)
 
 
+def update_pgsnapshot(module):
+    """Update Protection Group Snapshot - basically just rename..."""
+    array = get_array(module)
+    changed = True
+    if not module.check_mode:
+        current_name = module.params["name"] + "." + module.params["suffix"]
+        new_name = module.params["name"] + "." + module.params["target"]
+        res = array.patch_protection_group_snapshots(
+            names=[current_name],
+            protection_group_snapshot=ProtectionGroupSnapshotPatch(name=new_name),
+        )
+        if res.status_code != 200:
+            module.fail_json(
+                msg="Failed to rename {0} to {1}. Error: {2}".format(
+                    current_name, new_name, res.errors[0].message
+                )
+            )
+    module.exit_json(changed=changed)
+
+
 def main():
     argument_spec = purefa_argument_spec()
     argument_spec.update(
@@ -416,6 +505,7 @@ def main():
             suffix=dict(type="str"),
             restore=dict(type="str"),
             offload=dict(type="str"),
+            throttle=dict(type="bool", default=False),
             overwrite=dict(type="bool", default=False),
             target=dict(type="str"),
             eradicate=dict(type="bool", default=False),
@@ -423,17 +513,24 @@ def main():
             apply_retention=dict(type="bool", default=False),
             remote=dict(type="bool", default=False),
             state=dict(
-                type="str", default="present", choices=["absent", "present", "copy"]
+                type="str",
+                default="present",
+                choices=["absent", "present", "copy", "rename"],
             ),
         )
     )
 
     required_if = [("state", "copy", ["suffix", "restore"])]
+    mutually_exclusive = [["now", "remote"]]
 
     module = AnsibleModule(
-        argument_spec, required_if=required_if, supports_check_mode=True
+        argument_spec,
+        required_if=required_if,
+        mutually_exclusive=mutually_exclusive,
+        supports_check_mode=True,
     )
     state = module.params["state"]
+    pattern = re.compile("^(?=.*[a-zA-Z-])[a-zA-Z0-9]([a-zA-Z0-9-]{0,63}[a-zA-Z0-9])?$")
     if state == "present":
         if module.params["suffix"] is None:
             suffix = "snap-" + str(
@@ -445,10 +542,6 @@ def main():
                 pattern = re.compile(
                     "^[0-9]{0,63}$|^(?=.*[a-zA-Z-])[a-zA-Z0-9]([a-zA-Z0-9-]{0,63}[a-zA-Z0-9])?$"
                 )
-            else:
-                pattern = re.compile(
-                    "^(?=.*[a-zA-Z-])[a-zA-Z0-9]([a-zA-Z0-9-]{0,63}[a-zA-Z0-9])?$"
-                )
             if not pattern.match(module.params["suffix"]):
                 module.fail_json(
                     msg="Suffix name {0} does not conform to suffix name rules".format(
@@ -459,12 +552,27 @@ def main():
     if not module.params["target"] and module.params["restore"]:
         module.params["target"] = module.params["restore"]
 
+    if state == "rename" and module.params["target"] is not None:
+        if not pattern.match(module.params["target"]):
+            module.fail_json(
+                msg="Suffix target {0} does not conform to suffix name rules".format(
+                    module.params["target"]
+                )
+            )
     array = get_system(module)
     api_version = array._list_available_rest_versions()
+    if not HAS_PURESTORAGE and module.params["throttle"]:
+        module.warn(
+            "Throttle capability disable as py-pure-client sdk is not installed"
+        )
     if OFFLOAD_API not in api_version and module.params["offload"]:
         module.fail_json(
             msg="Minimum version {0} required for offload support".format(OFFLOAD_API)
         )
+    if POD_SNAPSHOT not in api_version and state == "offload":
+        module.fail_json(
+            msg="Minimum version {0} required for rename".format(POD_SNAPSHOT)
+        )
     pgroup = get_pgroup(module, array)
     if pgroup is None:
         module.fail_json(
@@ -491,7 +599,9 @@ def main():
         and get_offload_snapshot(module, array)
     ):
         delete_offload_snapshot(module, array)
-    elif state == "absent" and pgsnap:
+    elif state == "rename" and pgsnap:
+        update_pgsnapshot(module)
+    elif state == "absent" and pgsnap and not pgsnap_deleted:
         delete_pgsnapshot(module, array)
     elif state == "absent" and pgsnap and pgsnap_deleted and module.params["eradicate"]:
         eradicate_pgsnapshot(module, array)
